import requests  # type: ignore
import json
from requests.auth import HTTPBasicAuth  # type: ignore


def get_all_realm_users(realm_name="master", max_users=1000):
    """
    Get all users in a specified Keycloak realm.

    Args:
        realm_name (str): The name of the realm (default is "master")
        max_users (int): Maximum number of users to retrieve (default 1000)

    Returns:
        list: List of user objects or None if error
    """
    print(f"Retrieving all users from realm '{realm_name}'")

    with open("config.json", "r") as file:
        config = json.load(file)

    # Get token
    token_url = f"{config['keycloak_url']}/realms/master/protocol/openid-connect/token"
    token_data = {
        "grant_type": "password",
        "username": config["admin_username"],
        "password": config["admin_password"],
    }

    print("-- Getting authentication token")
    try:
        response = requests.post(
            token_url,
            data=token_data,
            auth=HTTPBasicAuth(config["client_id"], config["client_secret"]),
        )
        response.raise_for_status()
    except requests.exceptions.HTTPError as e:
        print(f"Error getting token: {e}")
        return None

    access_token = response.json()["access_token"]
    headers = {
        "Authorization": f"Bearer {access_token}",
        "Content-Type": "application/json",
    }

    # Get all users
    users_url = f"{config['keycloak_url']}/admin/realms/{realm_name}/users"
    params = {"max": max_users}  # Limit number of users returned

    print(f"-- Retrieving users from realm '{realm_name}'")
    try:
        response = requests.get(users_url, headers=headers, params=params)
        response.raise_for_status()
        users = response.json()
        print(f"-- Found {len(users)} users")
        return users
    except requests.exceptions.HTTPError as e:
        print(f"Error retrieving users: {e}")
        return None


users = get_all_realm_users(realm_name="master")


if users:
    # Print user information
    for user in users:
        print(
            f"ID: {user['id']}, Username: {user['username']}, Email: {user.get('email', 'No email')}"
        )
else:
    print("Failed to retrieve users")
